@@ -24,7 +24,7 @@ class ExchangeRate(bank.Bank):
             "Content-Type": "application/json",
             "Authorization": f"Bearer {token}",
         }
-        response = requests.post(url, headers=headers, data=payload,verify=False)
+        response = requests.post(url, headers=headers, json=payload,verify=False)
         if callback is not None:
             return callback(response)
         else:
